"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TypeScriptPackageGenerator = void 0;
const node_path_1 = __importDefault(require("node:path"));
const circleci_1 = require("../circleci");
const gitignore_1 = require("../gitignore");
const node_module_1 = require("../node-module");
const shared_1 = require("../shared");
const testing_1 = require("../testing");
const typescript_1 = require("../typescript");
class TypeScriptPackageGenerator extends shared_1.BaseGenerator {
    constructor(args, options) {
        super(args, options, { customInstallTask: true });
    }
    initializing() {
        this.composeWith([
            {
                Generator: gitignore_1.GitignoreGenerator,
                path: node_path_1.default.join(__dirname, "../gitignore"),
            },
            {
                Generator: node_module_1.NodeModuleGenerator,
                path: node_path_1.default.join(__dirname, "../node-module"),
            },
            {
                Generator: typescript_1.TypeScriptGenerator,
                path: node_path_1.default.join(__dirname, "../typescript"),
            },
            {
                Generator: testing_1.TestingGenerator,
                path: node_path_1.default.join(__dirname, "../testing"),
            },
            {
                Generator: circleci_1.CircleCiGenerator,
                path: node_path_1.default.join(__dirname, "../circleci"),
            },
        ]);
    }
    install() {
        const yarnArgs = ["install"];
        if (process.env.NODE_ENV === "test") {
            yarnArgs.push("--no-immutable");
        }
        this.spawnCommandSync("yarn", yarnArgs);
    }
}
exports.TypeScriptPackageGenerator = TypeScriptPackageGenerator;
//# sourceMappingURL=TypeScriptPackageGenerator.js.map