"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const node_path_1 = __importDefault(require("node:path"));
const yeoman_test_1 = __importDefault(require("yeoman-test"));
describe("JestGenerator", () => {
    let result;
    beforeAll(async () => {
        result = await yeoman_test_1.default.create(node_path_1.default.join(__dirname)).run();
    });
    describe(".gitignore", () => {
        it("ignores the reports directory", () => {
            result.assertFileContent(".gitignore", "reports");
        });
        it("ignores the coverage directory", () => {
            result.assertFileContent(".gitignore", "coverage");
        });
        it("ignores junit.xml", () => {
            result.assertFileContent(".gitignore", "junit.xml");
        });
    });
    describe("package.json", () => {
        describe("installs the necessary devDependencies", () => {
            it("installs jest", () => {
                expect(result).toHaveDevDependency("jest");
            });
            it("installs @types/jest", () => {
                expect(result).toHaveDevDependency("@types/jest");
            });
            it("installs ts-jest", () => {
                expect(result).toHaveDevDependency("ts-jest");
            });
            it("installs jest-junit", () => {
                expect(result).toHaveDevDependency("jest-junit");
            });
            it("installs ts-node", () => {
                expect(result).toHaveDevDependency("ts-node");
            });
            it("installs @types/node", () => {
                expect(result).toHaveDevDependency("@types/node");
            });
        });
        describe("updates the scripts section", () => {
            it("adds a test script", () => {
                result.assertJsonFileContent("package.json", {
                    scripts: {
                        test: "jest",
                    },
                });
            });
            it("adds a test:ci script", () => {
                result.assertJsonFileContent("package.json", {
                    scripts: {
                        "test:ci": "yarn run test --ci --runInBand --coverage --reporters=default --reporters=jest-junit",
                    },
                });
            });
        });
    });
    it("creates a jest.config.ts file", () => {
        result.assertFile("jest.config.ts");
    });
    it("creates an example test file", () => {
        result.assertFile("src/hello.test.ts");
    });
});
//# sourceMappingURL=JestGenerator.test.js.map